/* ETBToggleViews.jsx ------ UTF-8 -----------------------------------------------------------------
                 EditingDisplay and  PrintingDisplay (Substitute multi-code commands lost in FM-14)
   Documentation www.daube.ch/docu/fmaker73.html
   Comment       To be placed in Startup folder of user area
   Reference     Adobe: New Session-level scope for View menu commands: Earlier when you selected 
                 a command from the View menu, the command would impact only the active document.
                 However, from 2017 release, if you choose any command from the View menu, 
                 it will impact all documents opened in the current session. 
                 The following commands in the View menu affect the structured and unstructured documents:
                 • Borders  • Text Symbols  • Rulers  • Grid Lines  • Hotspot Indicators
                 Traduction française avec l'aide de Babylon et Deepl par Klaus Daube
   Attention     Code must be UTF-8. With Windows cp no umlauts etc. are allowed in menu items.
   Copyleft      2017 Klaus Daube, Zürich, Switzerland, klaus@daube.ch
   History       2017-006-30 v1.0 released:
                 2018-01-16 v 1.1 New command name
*/ ; // ===========================================================================================
#target framemaker  

var gasETBViewSettings = [];                      // save the user settings
var gsETBDisplaying_NoDoc   = { en: "No document active!",
                                de: "Kein dokument aktiv!",
                                fr: "Aucun document actif"};

SwitchUILanguage ();
SetUpMenu();                     // outcomment in debug
// SetPrintingDisplay ();        // activate in debug
// SetEditingDisplay ();         // activate in debug

function SetUpMenu() { // ==== Define the menu - even if not used =================================
var menuLocation, cmdDoc1, cmdDoc2;
  menuLocation = app.GetNamedMenu("ETBmenu");     // Required, even if not used
  cmdDoc1 = DefineCommand (1, "ETB_EditingDisplay",  "Document Editing Display [ETB]",  "\\!qqe"); 
  cmdDoc2 = DefineCommand (2, "ETB_PrintingDisplay", "Document Printing Display [ETB]", "\\!qqp"); 
  UpdateMenus();
// alert ("Menu should have been set up");        // passes here
} // --- end SetUpMenu

function Command(cmd) { // ==== Respond to menu/TB command ========================================
	switch(cmd)  {
		case 1: 
      SetEditingDisplay();
      break;
		case 2: 
      SetPrintingDisplay();
      break;
    }
} // --- end Command

function SetEditingDisplay () { // === Set view properties for Editing ============================
var oDoc,
    cmd0 = app.GetNamedCommand ("ViewBorders"),       // these are all toggles
    cmd1 = app.GetNamedCommand ("ViewTextSymbols"),
    cmd2 = app.GetNamedCommand ("ViewRulers"),
    cmd3 = app.GetNamedCommand ("ViewGridLines"),
    cmd4 = app.GetNamedCommand ("ToggleGraphicsDisplay");

if (!app.ActiveDoc.ObjectValid()) {
    alert ("ETBToggleViews: " + localize (gsETBDisplaying_NoDoc));
    return;
  }
  oDoc = app.ActiveDoc;
  if (oDoc.ViewBorders == 0) {
    Fcodes ([cmd0.Fcode]);                        // => set Borders      ON 
  }    
  if (oDoc.ViewTextSymbols == 0) {
    Fcodes ([cmd1.Fcode]);                        // => set Textsymbols  ON
  }
//--- Leave rulers, grid and graphics as the user have set them before printing view
  if (oDoc.ViewRulers != gasETBViewSettings [2]) { 
    Fcodes ([cmd2.Fcode])                         // => set Rulers
  }
  if (oDoc.ViewGrid != gasETBViewSettings [3]) {
    Fcodes ([cmd3.Fcode])                         // => set Gridlines 
  }
  if (oDoc.ViewNoGraphics != gasETBViewSettings [4]) {
    Fcodes ([cmd4.Fcode])                         // => set Graphics
  }
  return;
} // --- end SetEditingDisplay

function SetPrintingDisplay () { // === Set view properties for Printing ==========================
var oDoc,
    cmd0 = app.GetNamedCommand ("ViewBorders"),       // these are all toggles
    cmd1 = app.GetNamedCommand ("ViewTextSymbols"),
    cmd2 = app.GetNamedCommand ("ViewRulers"),
    cmd3 = app.GetNamedCommand ("ViewGridLines"),
    cmd4 = app.GetNamedCommand ("ToggleGraphicsDisplay");
    
  if (!app.ActiveDoc.ObjectValid()) {
    alert ("ETBToggleViews: " + localize (gsETBDisplaying_NoDoc));
    return;
  }
  oDoc = app.ActiveDoc;
  gasETBViewSettings [0] = oDoc.ViewBorders; // save previous view
  gasETBViewSettings [1] = oDoc.ViewTextSymbols;
  gasETBViewSettings [2] = oDoc.ViewRulers;
  gasETBViewSettings [3] = oDoc.ViewGrid;
  gasETBViewSettings [4] = oDoc.ViewNoGraphics;
  if (oDoc.ViewBorders == 1) {
    Fcodes ([cmd0.Fcode]);                        // => set Borders      OFF 
  }    
  if (oDoc.ViewTextSymbols == 1) {
    Fcodes ([cmd1.Fcode]);                        // => set Textsymbols  OFF
  }
  if (oDoc.ViewRulers == 1) { 
    Fcodes ([cmd2.Fcode])                         // => set Rulers       OFF
  }
  if (oDoc.ViewGrid == 1) {
    Fcodes ([cmd3.Fcode])                         // => set Gridlines    OFF
  }
  if (oDoc.ViewNoGraphics == 1) {
    Fcodes ([cmd4.Fcode])                         // => set Graphics     On
  }
  return;
} // --- end SetPrintingDisplay

function SetupNotifications () { // Watch for the following notifications ========================= 
  Notification (Constants.FA_Note_PostActiveDocChange, true);  
} // --- end SetupNotifications

function Notify (note, object, sparam, iparam) {  // Handle triggered events ======================
  if (typeof  object == "undefined") {return;}    // just started in StartUp folder
  switch (note) {
    case Constants.FA_Note_PostActiveDocChange:   // active document has changed
      if (!app.ActiveDoc.ObjectValid() && !app.ActiveBook.ObjectValid()) {
        alert (localize (gsMsgNoDoc));
        return;
      } else {
        if (app.ActiveDoc.ObjectValid()){
//        goActiveDoc = object;
        } else {
//        goActiveBook = object;
        }
      }
    break;
    
    default:	                                    // unknown notification
  }
} // --- end Notify

function SwitchUILanguage () {; // === Switch language according to application language ============
  switch (app.Language) {
    case Constants.FV_LANG_BRITISH:
    case Constants.FV_LANG_ENGLISH: {
      $.locale = "en"; break; 
    }
    case Constants.FV_LANG_CANADIAN_FRENCH: 
    case Constants.FV_LANG_FRENCH: {
      $.locale = "fr"; break; 
    }
    case Constants.FV_LANG_GERMAN: 
    case Constants.FV_LANG_NEW_GERMAN: 
    case Constants.FV_LANG_NEW_SWISS_GERMAN:	
    case Constants.FV_LANG_SWISS_GERMAN:	{
      $.locale = "de"; break; 
    }
    default: {
      $.locale = "en"; break; 
    }
  }
} // --- end SwitchUILanguage
